# How to customize the style of Vizro dashboards

Vizro has a default styling to help users with no design experience get started. There are several options if you want to customize the style:

- **[Configure the `Layout`](layouts.md)**: Customize the arrangement of your components inside your Vizro dashboard.

- **[Apply a theme](themes.md)**: Choose between a dark or light theme.

- **[Manage assets](assets.md)**: Enhance your dashboard by adding images, scripts, and stylesheets to your assets folder.

- **[Customize CSS](custom-css.md)**: Incorporate custom CSS to deviate from the default styling and create a unique appearance for your Vizro dashboard.

- **[Customize your `component`](components.md)**: Change the appearance of components like the [Graph](graph.md), the [Table](table.md) and the [AgGrid](table.md), by passing extra arguments. Refer to the relevant user guide for more details.
